@@ -7,7 +7,7 @@ local machine and Plotly. Almost all functionality used here will require a
 verifiable account (username/api-key pair) and a network connection.
 
 """
-from plotly import *
+from .plotly import *
 
 __all__ = ["sign_in", "update_plot_options", "get_plot_options",
            "get_credentials", "iplot", "plot", "iplot_mpl", "plot_mpl",
