@@ -14,17 +14,21 @@ and ploty's servers.
 4. update plot_options with kwargs!
 
 """
-import requests
-import chunked_requests
 import json
 import warnings
 import copy
 import os
+import six
+
+import requests
+
+from . import chunked_requests
 from .. import utils  # TODO make non-relative
 from .. import tools
 from .. import exceptions
 from .. import version
 
+
 __all__ = ["sign_in", "update_plot_options", "get_plot_options",
            "get_credentials", "iplot", "plot", "iplot_mpl", "plot_mpl",
            "get_figure", "Stream", "image"]
@@ -160,7 +164,7 @@ def plot(figure_or_data, validate=True, **plot_options):
                                          "plot option.\nHere's why you're "
                                          "seeing this error:\n\n{}".format(err))
     for entry in figure['data']:
-        for key, val in entry.items():
+        for key, val in list(entry.items()):
             try:
                 if len(val) > 40000:
                     msg = ("Woah there! Look at all those points! Due to "
@@ -333,7 +337,10 @@ def get_figure(file_owner_or_url, file_id=None, raw=False):
         )
     response = requests.get(plotly_rest_url + resource, headers=headers)
     if response.status_code == 200:
-        content = json.loads(response.content)
+        if six.PY3:
+            content = json.loads(response.content.decode('unicode_escape'))
+        else:
+            content = json.loads(response.content)
         response_payload = content['payload']
         figure = response_payload['figure']
         utils.decode_unicode(figure)
@@ -658,11 +665,11 @@ def _send_to_plotly(figure, **plot_options):
     r.raise_for_status()
     r = json.loads(r.text)
     if 'error' in r and r['error'] != '':
-        print(r['error'])
+        print((r['error']))
     if 'warning' in r and r['warning'] != '':
         warnings.warn(r['warning'])
     if 'message' in r and r['message'] != '':
-        print(r['message'])
+        print((r['message']))
 
     return r
 
